from __future__ import unicode_literals
import sys
import argparse
import logging
import time
import threading
import ipfix.ie
import ipfix.reader
import ipfix.message
import socketserver
import socket

class IPFixDatagramHandler (socketserver.DatagramRequestHandler):

    def handle (self):
        logging.info (f'Connection from {self.client_address}')
        try:
            self.server.msg_buffer.from_bytes (self.packet)
            for rec in self.server.msg_buffer.namedict_iterator ():
                logging.info (f't: {self.server.msg_buffer.get_export_time()}: {rec}')
        except:
            logging.error ('Unexpected exception:', sys.exc_info ()[0])


class IPFixUdpServer (socketserver.UDPServer):

    def __init__ (self, *args, **kwargs):

        self.msg_buffer = ipfix.message.MessageBuffer ()
        super ().__init__ (*args, **kwargs)

class IPFixStreamHandler (socketserver.StreamRequestHandler):

    def handle (self):
        logging.info (f'Connection from {self.client_address}')
        try:
            msg_reader = ipfix.reader.from_stream (self.rfile)
            for rec in msg_reader.namedict_iterator ():
                logging.info (f't: {msg_reader.msg.get_export_time()}: {rec}')
            logging.info (f'{self.client_address} closed their connection')
        except ConnectionResetError:
            logging.info (f'{self.client_address} connection reset')
        except TimeoutError:
            logging.info (f'{self.client_address} connection timed out')
        except:
            logging.error ('Unexpected exception:', sys.exc_info ()[0])
        

if __name__ == "__main__":
    INTERFACE, PORT = '', 4739

    ap = argparse.ArgumentParser (description='Dump IPFIX data collected over UDP')
    ap.add_argument ('-l', '--log', metavar='loglevel', default='WARNING', help='logging level')
    ap.add_argument ('-s', '--spec', metavar='specfile', help='iespec file to read')
    args = ap.parse_args ()

    log_level = getattr (logging, args.log.upper (), None)
    if not isinstance (log_level, int):
        raise ValueError (f'Invalif log level: {log_level}')
    logging.basicConfig (
        level=log_level
        , format='[%(levelname)s] (%(threadName)-10s) %(message)s'
        ,
        )

    logging.info (f'Starting IPFix servers on service port: {PORT}')

    ipfix.ie.use_iana_default ()
    ipfix.ie.use_5103_default ()
    if args.spec:
        ipfix.ie.use_specfile (args.spec)

    udp_server = IPFixUdpServer ((INTERFACE, PORT), IPFixDatagramHandler)
    udp_thread = threading.Thread (name='UDP Server', target=udp_server.serve_forever)

    tcp_server = socketserver.TCPServer ((INTERFACE, PORT), IPFixStreamHandler)
    tcp_server.allow_reuse_address = True
    tcp_server.socket.setsockopt (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
    tcp_thread = threading.Thread (name='TCP/IP Server', target=tcp_server.serve_forever)

    udp_thread.start ()
    tcp_thread.start ()

    try:
        while True:
            time.sleep (1000)
    except KeyboardInterrupt:
        logging.warning ('Closing down servers')
        udp_server.shutdown ()
        tcp_server.shutdown ()

    udp_thread.join ()
    tcp_thread.join ()
    logging.info ('Servers closed')



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_widgets.ui'
#
# Created: Thu Dec 13 17:14:05 2018
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(269, 306)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName("gridLayout")
        self.label_81 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_81.setFont(font)
        self.label_81.setObjectName("label_81")
        self.gridLayout.addWidget(self.label_81, 0, 1, 1, 1)
        self.label_82 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_82.setFont(font)
        self.label_82.setObjectName("label_82")
        self.gridLayout.addWidget(self.label_82, 0, 2, 1, 1)
        self.label_56 = QtGui.QLabel(self.dockWidgetContents)
        self.label_56.setMinimumSize(QtCore.QSize(0, 0))
        self.label_56.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_56.setFont(font)
        self.label_56.setObjectName("label_56")
        self.gridLayout.addWidget(self.label_56, 1, 0, 1, 1)
        self.listWidget = QtGui.QListWidget(self.dockWidgetContents)
        self.listWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.listWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.listWidget.setObjectName("listWidget")
        QtGui.QListWidgetItem(self.listWidget)
        QtGui.QListWidgetItem(self.listWidget)
        QtGui.QListWidgetItem(self.listWidget)
        QtGui.QListWidgetItem(self.listWidget)
        self.gridLayout.addWidget(self.listWidget, 1, 1, 1, 1)
        self.listWidgetDis = QtGui.QListWidget(self.dockWidgetContents)
        self.listWidgetDis.setEnabled(False)
        self.listWidgetDis.setObjectName("listWidgetDis")
        QtGui.QListWidgetItem(self.listWidgetDis)
        QtGui.QListWidgetItem(self.listWidgetDis)
        QtGui.QListWidgetItem(self.listWidgetDis)
        QtGui.QListWidgetItem(self.listWidgetDis)
        self.gridLayout.addWidget(self.listWidgetDis, 1, 2, 1, 1)
        self.label_57 = QtGui.QLabel(self.dockWidgetContents)
        self.label_57.setMinimumSize(QtCore.QSize(0, 0))
        self.label_57.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_57.setFont(font)
        self.label_57.setObjectName("label_57")
        self.gridLayout.addWidget(self.label_57, 2, 0, 1, 1)
        self.treeWidget = QtGui.QTreeWidget(self.dockWidgetContents)
        self.treeWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.treeWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.treeWidget.setObjectName("treeWidget")
        item_0 = QtGui.QTreeWidgetItem(self.treeWidget)
        item_1 = QtGui.QTreeWidgetItem(item_0)
        item_2 = QtGui.QTreeWidgetItem(item_1)
        item_0 = QtGui.QTreeWidgetItem(self.treeWidget)
        item_1 = QtGui.QTreeWidgetItem(item_0)
        self.gridLayout.addWidget(self.treeWidget, 2, 1, 1, 1)
        self.treeWidgetDis = QtGui.QTreeWidget(self.dockWidgetContents)
        self.treeWidgetDis.setEnabled(False)
        self.treeWidgetDis.setObjectName("treeWidgetDis")
        item_0 = QtGui.QTreeWidgetItem(self.treeWidgetDis)
        item_1 = QtGui.QTreeWidgetItem(item_0)
        item_2 = QtGui.QTreeWidgetItem(item_1)
        item_0 = QtGui.QTreeWidgetItem(self.treeWidgetDis)
        item_1 = QtGui.QTreeWidgetItem(item_0)
        self.gridLayout.addWidget(self.treeWidgetDis, 2, 2, 1, 1)
        self.label_58 = QtGui.QLabel(self.dockWidgetContents)
        self.label_58.setMinimumSize(QtCore.QSize(0, 0))
        self.label_58.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_58.setFont(font)
        self.label_58.setObjectName("label_58")
        self.gridLayout.addWidget(self.label_58, 3, 0, 1, 1)
        self.tableWidget = QtGui.QTableWidget(self.dockWidgetContents)
        self.tableWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.tableWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.tableWidget.setObjectName("tableWidget")
        self.tableWidget.setColumnCount(2)
        self.tableWidget.setRowCount(3)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setVerticalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(0, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(0, 1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(1, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(1, 1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(2, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget.setItem(2, 1, item)
        self.gridLayout.addWidget(self.tableWidget, 3, 1, 1, 1)
        self.tableWidgetDis = QtGui.QTableWidget(self.dockWidgetContents)
        self.tableWidgetDis.setEnabled(False)
        self.tableWidgetDis.setObjectName("tableWidgetDis")
        self.tableWidgetDis.setColumnCount(2)
        self.tableWidgetDis.setRowCount(3)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setVerticalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setVerticalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setVerticalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(0, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(0, 1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(1, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(1, 1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(2, 0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidgetDis.setItem(2, 1, item)
        self.gridLayout.addWidget(self.tableWidgetDis, 3, 2, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(QtGui.QApplication.translate("DockWidget", "Widgets", None, QtGui.QApplication.UnicodeUTF8))
        self.label_81.setText(QtGui.QApplication.translate("DockWidget", "Enabled", None, QtGui.QApplication.UnicodeUTF8))
        self.label_82.setText(QtGui.QApplication.translate("DockWidget", "Disabled", None, QtGui.QApplication.UnicodeUTF8))
        self.label_56.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_56.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_56.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_56.setText(QtGui.QApplication.translate("DockWidget", "ListWidget", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidget.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidget.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidget.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        __sortingEnabled = self.listWidget.isSortingEnabled()
        self.listWidget.setSortingEnabled(False)
        self.listWidget.item(0).setText(QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidget.item(1).setText(QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidget.item(2).setText(QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidget.item(3).setText(QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidget.setSortingEnabled(__sortingEnabled)
        __sortingEnabled = self.listWidgetDis.isSortingEnabled()
        self.listWidgetDis.setSortingEnabled(False)
        self.listWidgetDis.item(0).setText(QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidgetDis.item(1).setText(QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidgetDis.item(2).setText(QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidgetDis.item(3).setText(QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.listWidgetDis.setSortingEnabled(__sortingEnabled)
        self.label_57.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_57.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_57.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_57.setText(QtGui.QApplication.translate("DockWidget", "TreeWidget", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.setSortingEnabled(True)
        self.treeWidget.headerItem().setText(0, QtGui.QApplication.translate("DockWidget", "New Column", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.headerItem().setText(1, QtGui.QApplication.translate("DockWidget", "New Column", None, QtGui.QApplication.UnicodeUTF8))
        __sortingEnabled = self.treeWidget.isSortingEnabled()
        self.treeWidget.setSortingEnabled(False)
        self.treeWidget.topLevelItem(0).setText(0, QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.topLevelItem(0).child(0).setText(0, QtGui.QApplication.translate("DockWidget", "New Subitem", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.topLevelItem(0).child(0).setText(1, QtGui.QApplication.translate("DockWidget", "Test", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.topLevelItem(0).child(0).child(0).setText(0, QtGui.QApplication.translate("DockWidget", "New Subitem", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.topLevelItem(1).setText(0, QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.topLevelItem(1).child(0).setText(0, QtGui.QApplication.translate("DockWidget", "New Subitem", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget.setSortingEnabled(__sortingEnabled)
        self.treeWidgetDis.setSortingEnabled(True)
        self.treeWidgetDis.headerItem().setText(0, QtGui.QApplication.translate("DockWidget", "New Column", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidgetDis.headerItem().setText(1, QtGui.QApplication.translate("DockWidget", "New Column", None, QtGui.QApplication.UnicodeUTF8))
        __sortingEnabled = self.treeWidgetDis.isSortingEnabled()
        self.treeWidgetDis.setSortingEnabled(False)
        self.treeWidgetDis.topLevelItem(0).setText(0, QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidgetDis.topLevelItem(0).child(0).setText(0, QtGui.QApplication.translate("DockWidget", "New Subitem", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidgetDis.topLevelItem(0).child(0).setText(1, QtGui.QApplication.translate("DockWidget", "Test", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidgetDis.topLevelItem(0).child(0).child(0).setText(0, QtGui.QApplication.translate("DockWidget", "New Subitem", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidgetDis.topLevelItem(1).setText(0, QtGui.QApplication.translate("DockWidget", "New Item", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidgetDis.topLevelItem(1).child(0).setText(0, QtGui.QApplication.translate("DockWidget", "New Subitem", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidgetDis.setSortingEnabled(__sortingEnabled)
        self.label_58.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_58.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_58.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_58.setText(QtGui.QApplication.translate("DockWidget", "TableWidget", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.verticalHeaderItem(0).setText(QtGui.QApplication.translate("DockWidget", "New Row", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.verticalHeaderItem(1).setText(QtGui.QApplication.translate("DockWidget", "New Row", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.verticalHeaderItem(2).setText(QtGui.QApplication.translate("DockWidget", "New Row", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.horizontalHeaderItem(0).setText(QtGui.QApplication.translate("DockWidget", "New Column", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.horizontalHeaderItem(1).setText(QtGui.QApplication.translate("DockWidget", "New Column", None, QtGui.QApplication.UnicodeUTF8))
        __sortingEnabled = self.tableWidget.isSortingEnabled()
        self.tableWidget.setSortingEnabled(False)
        self.tableWidget.item(0, 0).setText(QtGui.QApplication.translate("DockWidget", "1.23", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.item(0, 1).setText(QtGui.QApplication.translate("DockWidget", "Hello", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.item(1, 0).setText(QtGui.QApplication.translate("DockWidget", "1,45", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.item(1, 1).setText(QtGui.QApplication.translate("DockWidget", "Olá", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.item(2, 0).setText(QtGui.QApplication.translate("DockWidget", "12/12/2012", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.item(2, 1).setText(QtGui.QApplication.translate("DockWidget", "Oui", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget.setSortingEnabled(__sortingEnabled)
        self.tableWidgetDis.verticalHeaderItem(0).setText(QtGui.QApplication.translate("DockWidget", "New Row", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.verticalHeaderItem(1).setText(QtGui.QApplication.translate("DockWidget", "New Row", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.verticalHeaderItem(2).setText(QtGui.QApplication.translate("DockWidget", "New Row", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.horizontalHeaderItem(0).setText(QtGui.QApplication.translate("DockWidget", "New Column", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.horizontalHeaderItem(1).setText(QtGui.QApplication.translate("DockWidget", "New Column", None, QtGui.QApplication.UnicodeUTF8))
        __sortingEnabled = self.tableWidgetDis.isSortingEnabled()
        self.tableWidgetDis.setSortingEnabled(False)
        self.tableWidgetDis.item(0, 0).setText(QtGui.QApplication.translate("DockWidget", "1.23", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.item(0, 1).setText(QtGui.QApplication.translate("DockWidget", "Hello", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.item(1, 0).setText(QtGui.QApplication.translate("DockWidget", "1,45", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.item(1, 1).setText(QtGui.QApplication.translate("DockWidget", "Olá", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.item(2, 0).setText(QtGui.QApplication.translate("DockWidget", "12/12/2012", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.item(2, 1).setText(QtGui.QApplication.translate("DockWidget", "Oui", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidgetDis.setSortingEnabled(__sortingEnabled)




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mw_menus.ui'
#
# Created: Thu Dec 13 17:14:05 2018
#      by: pyside2-uic 2.0.0 running on PySide2 5.6.0~a1
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(596, 569)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.groupBox_2 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout.setObjectName("gridLayout")
        self.tabWidget = QtWidgets.QTabWidget(self.groupBox_2)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.label_2 = QtWidgets.QLabel(self.groupBox_3)
        self.label_2.setObjectName("label_2")
        self.gridLayout_5.addWidget(self.label_2, 0, 0, 1, 1)
        self.lineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.lineEdit.setObjectName("lineEdit")
        self.gridLayout_5.addWidget(self.lineEdit, 0, 1, 1, 1)
        self.frame = QtWidgets.QFrame(self.groupBox_3)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.formLayout = QtWidgets.QFormLayout(self.frame)
        self.formLayout.setObjectName("formLayout")
        self.label_3 = QtWidgets.QLabel(self.frame)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.lineEdit_2 = QtWidgets.QLineEdit(self.frame)
        self.lineEdit_2.setObjectName("lineEdit_2")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lineEdit_2)
        self.gridLayout_5.addWidget(self.frame, 1, 0, 1, 2)
        self.gridLayout_4.addWidget(self.groupBox_3, 1, 0, 1, 1)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.tab_2)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.label_4 = QtWidgets.QLabel(self.tab_2)
        self.label_4.setObjectName("label_4")
        self.gridLayout_6.addWidget(self.label_4, 0, 0, 1, 1)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.tabWidget.addTab(self.tab_3, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.tabWidget.addTab(self.tab_4, "")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.tabWidget.addTab(self.tab_5, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.tabWidget.addTab(self.tab_6, "")
        self.tab_7 = QtWidgets.QWidget()
        self.tab_7.setObjectName("tab_7")
        self.tabWidget.addTab(self.tab_7, "")
        self.tab_8 = QtWidgets.QWidget()
        self.tab_8.setObjectName("tab_8")
        self.tabWidget.addTab(self.tab_8, "")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.tabWidget.addTab(self.tab_9, "")
        self.tab_10 = QtWidgets.QWidget()
        self.tab_10.setObjectName("tab_10")
        self.tabWidget.addTab(self.tab_10, "")
        self.tab_11 = QtWidgets.QWidget()
        self.tab_11.setObjectName("tab_11")
        self.tabWidget.addTab(self.tab_11, "")
        self.tab_12 = QtWidgets.QWidget()
        self.tab_12.setObjectName("tab_12")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tab_12)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.tabWidget.addTab(self.tab_12, "")
        self.gridLayout.addWidget(self.tabWidget, 0, 0, 1, 1)
        self.gridLayout_7.addWidget(self.groupBox_2, 0, 0, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setLineWidth(0)
        self.label.setTextFormat(QtCore.Qt.RichText)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setWordWrap(True)
        self.label.setOpenExternalLinks(True)
        self.label.setTextInteractionFlags(QtCore.Qt.TextBrowserInteraction)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 1)
        self.gridLayout_7.addWidget(self.groupBox, 1, 0, 1, 1)
        self.label_71 = QtWidgets.QLabel(self.centralwidget)
        self.label_71.setAlignment(QtCore.Qt.AlignCenter)
        self.label_71.setObjectName("label_71")
        self.gridLayout_7.addWidget(self.label_71, 2, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 596, 28))
        self.menubar.setObjectName("menubar")
        self.menuMenu = QtWidgets.QMenu(self.menubar)
        self.menuMenu.setObjectName("menuMenu")
        self.menuMenuSub = QtWidgets.QMenu(self.menuMenu)
        self.menuMenuSub.setObjectName("menuMenuSub")
        self.menuMenuDelayed = QtWidgets.QMenu(self.menubar)
        self.menuMenuDelayed.setObjectName("menuMenuDelayed")
        self.menuMenuSubDelayed = QtWidgets.QMenu(self.menuMenuDelayed)
        self.menuMenuSubDelayed.setObjectName("menuMenuSubDelayed")
        self.menuMenuCheckale = QtWidgets.QMenu(self.menubar)
        self.menuMenuCheckale.setObjectName("menuMenuCheckale")
        self.menuAbout = QtWidgets.QMenu(self.menubar)
        self.menuAbout.setObjectName("menuAbout")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtWidgets.QToolBar(MainWindow)
        self.toolBar.setObjectName("toolBar")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.toolBarDelayed = QtWidgets.QToolBar(MainWindow)
        self.toolBarDelayed.setObjectName("toolBarDelayed")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBarDelayed)
        self.toolBarCheckable = QtWidgets.QToolBar(MainWindow)
        self.toolBarCheckable.setObjectName("toolBarCheckable")
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBarCheckable)
        MainWindow.insertToolBarBreak(self.toolBarCheckable)
        self.actionActionA = QtWidgets.QAction(MainWindow)
        self.actionActionA.setObjectName("actionActionA")
        self.actionActionSubA = QtWidgets.QAction(MainWindow)
        self.actionActionSubA.setObjectName("actionActionSubA")
        self.actionActionSubB = QtWidgets.QAction(MainWindow)
        self.actionActionSubB.setObjectName("actionActionSubB")
        self.actionActionDelayedA = QtWidgets.QAction(MainWindow)
        self.actionActionDelayedA.setObjectName("actionActionDelayedA")
        self.actionActionDelayedSubA = QtWidgets.QAction(MainWindow)
        self.actionActionDelayedSubA.setObjectName("actionActionDelayedSubA")
        self.actionActionCheckableA = QtWidgets.QAction(MainWindow)
        self.actionActionCheckableA.setCheckable(True)
        self.actionActionCheckableA.setObjectName("actionActionCheckableA")
        self.actionActionCheckableSubAChecked = QtWidgets.QAction(MainWindow)
        self.actionActionCheckableSubAChecked.setCheckable(True)
        self.actionActionCheckableSubAChecked.setChecked(True)
        self.actionActionCheckableSubAChecked.setObjectName("actionActionCheckableSubAChecked")
        self.actionActionCheckableSubAUnchecked = QtWidgets.QAction(MainWindow)
        self.actionActionCheckableSubAUnchecked.setCheckable(True)
        self.actionActionCheckableSubAUnchecked.setObjectName("actionActionCheckableSubAUnchecked")
        self.menuMenuSub.addAction(self.actionActionSubA)
        self.menuMenuSub.addAction(self.actionActionSubB)
        self.menuMenu.addAction(self.actionActionA)
        self.menuMenu.addAction(self.menuMenuSub.menuAction())
        self.menuMenuSubDelayed.addAction(self.actionActionDelayedSubA)
        self.menuMenuDelayed.addAction(self.actionActionDelayedA)
        self.menuMenuDelayed.addAction(self.menuMenuSubDelayed.menuAction())
        self.menuMenuCheckale.addAction(self.actionActionCheckableA)
        self.menubar.addAction(self.menuMenu.menuAction())
        self.menubar.addAction(self.menuMenuDelayed.menuAction())
        self.menubar.addAction(self.menuMenuCheckale.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.menubar.addAction(self.menuAbout.menuAction())
        self.toolBar.addAction(self.actionActionA)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionActionSubA)
        self.toolBar.addAction(self.actionActionSubB)
        self.toolBarDelayed.addAction(self.actionActionDelayedA)
        self.toolBarDelayed.addSeparator()
        self.toolBarDelayed.addAction(self.actionActionDelayedSubA)
        self.toolBarCheckable.addAction(self.actionActionCheckableA)
        self.toolBarCheckable.addSeparator()
        self.toolBarCheckable.addAction(self.actionActionCheckableSubAChecked)
        self.toolBarCheckable.addAction(self.actionActionCheckableSubAUnchecked)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.lineEdit, self.tabWidget)
        MainWindow.setTabOrder(self.tabWidget, self.lineEdit_2)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "MainWindow", None, -1))
        self.groupBox_2.setTitle(QtWidgets.QApplication.translate("MainWindow", "Issue #115 - Tabs scroller buttons", None, -1))
        self.groupBox_3.setTitle(QtWidgets.QApplication.translate("MainWindow", "Issue #123 - Missing borders", None, -1))
        self.label_2.setText(QtWidgets.QApplication.translate("MainWindow", "TextLabel", None, -1))
        self.lineEdit.setText(QtWidgets.QApplication.translate("MainWindow", "Inside tab, outside frame", None, -1))
        self.label_3.setText(QtWidgets.QApplication.translate("MainWindow", "TextLabel", None, -1))
        self.lineEdit_2.setText(QtWidgets.QApplication.translate("MainWindow", "Inside tab and frame", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtWidgets.QApplication.translate("MainWindow", "Tab 1", None, -1))
        self.label_4.setText(QtWidgets.QApplication.translate("MainWindow", "TextLabel", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtWidgets.QApplication.translate("MainWindow", "Tab 2", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_6), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_7), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_8), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_9), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_10), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_11), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_12), QtWidgets.QApplication.translate("MainWindow", "Page", None, -1))
        self.groupBox.setTitle(QtWidgets.QApplication.translate("MainWindow", "Issue #112 - Hyperlinks color", None, -1))
        self.label.setText(QtWidgets.QApplication.translate("MainWindow", "<html><head/><body><p align=\"center\"><a href=\"https://github.com/ColinDuquesnoy/QDarkStyleSheet/issues/112\"><span style=\" font-size:10pt; text-decoration: underline; color:#0000ff;\">Hyperlink Example</span></a></p><p align=\"center\"><span style=\" font-size:10pt; color:#7d7d7d;\">CSS for the documents (RichText) is not the same as the application. We cannot change the internal content CSS, e.g., hyperlinks. We suggest you use the middle tons (0-255, use 125), so this works for both white and dark theme (this color). The original color is the blue link on top.</span></p><p align=\"center\"><br/></p></body></html>", None, -1))
        self.label_71.setText(QtWidgets.QApplication.translate("MainWindow", "Inside Central Widget", None, -1))
        self.menuMenu.setTitle(QtWidgets.QApplication.translate("MainWindow", "Menu", None, -1))
        self.menuMenuSub.setTitle(QtWidgets.QApplication.translate("MainWindow", "Menu Sub", None, -1))
        self.menuMenuDelayed.setTitle(QtWidgets.QApplication.translate("MainWindow", "Menu Delayed", None, -1))
        self.menuMenuSubDelayed.setTitle(QtWidgets.QApplication.translate("MainWindow", "Menu Sub Delayed", None, -1))
        self.menuMenuCheckale.setTitle(QtWidgets.QApplication.translate("MainWindow", "Menu Checkable", None, -1))
        self.menuAbout.setTitle(QtWidgets.QApplication.translate("MainWindow", "About QDarkStyle", None, -1))
        self.menuHelp.setTitle(QtWidgets.QApplication.translate("MainWindow", "Help", None, -1))
        self.toolBar.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "Tool bar actions", None, -1))
        self.toolBarDelayed.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "Tool bar actions delayed", None, -1))
        self.toolBarCheckable.setWindowTitle(QtWidgets.QApplication.translate("MainWindow", "Tool bar action checkable", None, -1))
        self.actionActionA.setText(QtWidgets.QApplication.translate("MainWindow", "Action A", None, -1))
        self.actionActionSubA.setText(QtWidgets.QApplication.translate("MainWindow", "Action A Sub", None, -1))
        self.actionActionSubA.setToolTip(QtWidgets.QApplication.translate("MainWindow", "Action A Sub", None, -1))
        self.actionActionSubB.setText(QtWidgets.QApplication.translate("MainWindow", "Action B Sub", None, -1))
        self.actionActionDelayedA.setText(QtWidgets.QApplication.translate("MainWindow", "Action Delayed A", None, -1))
        self.actionActionDelayedA.setToolTip(QtWidgets.QApplication.translate("MainWindow", "Action Delayed A", None, -1))
        self.actionActionDelayedSubA.setText(QtWidgets.QApplication.translate("MainWindow", "Action Delayed Sub A", None, -1))
        self.actionActionDelayedSubA.setToolTip(QtWidgets.QApplication.translate("MainWindow", "Action Delayed Sub A", None, -1))
        self.actionActionCheckableA.setText(QtWidgets.QApplication.translate("MainWindow", "Action Checkable A", None, -1))
        self.actionActionCheckableA.setToolTip(QtWidgets.QApplication.translate("MainWindow", "Action Checkable A", None, -1))
        self.actionActionCheckableSubAChecked.setText(QtWidgets.QApplication.translate("MainWindow", "Action Checkable Sub A Checked", None, -1))
        self.actionActionCheckableSubAChecked.setToolTip(QtWidgets.QApplication.translate("MainWindow", "Action Checkable Sub A Checked", None, -1))
        self.actionActionCheckableSubAUnchecked.setText(QtWidgets.QApplication.translate("MainWindow", "Action Checkable Sub A Unchecked", None, -1))
        self.actionActionCheckableSubAUnchecked.setToolTip(QtWidgets.QApplication.translate("MainWindow", "Action Checkable Sub A Unchecked", None, -1))




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Process qrc and ui files, then run example in while loop."""

from __future__ import absolute_import, print_function

import sys
from subprocess import call


def main():
    """Process qrc and ui files, then run example in while loop."""
    dark = None
    no_dark = None

    while True:
        try:
            dark.kill()
        except AttributeError:
            print('Dark not running!')
        except Exception:
            print('Dark still running!')
        else:
            print('Dark was killed!')

        try:
            no_dark.kill()
        except AttributeError:
            print('No Dark not running!')
        except Exception:
            print('No Dark still running!')
        else:
            print('No Dark was killed!')

        print(sys.argv)

        # process qrc files
        call(['python', 'process_qrc.py'])
        # process ui files
        call(['python', 'process_ui.py'])
        # open dark example
        dark = call(['python', '../example/example.py'] + sys.argv[1:])
        # open no dark example
        no_dark = call(['python', '../example/example.py', '--no_dark'] + sys.argv[1:])

        if dark or no_dark:
            print('Unf! It not worked! Please, check the error(s).')
            break


if __name__ == "__main__":
    sys.exit(main())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_containers_no_tabs.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName(_fromUtf8("DockWidget"))
        DockWidget.resize(497, 566)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.gridLayout_45 = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout_45.setObjectName(_fromUtf8("gridLayout_45"))
        self.label_126 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_126.setFont(font)
        self.label_126.setObjectName(_fromUtf8("label_126"))
        self.gridLayout_45.addWidget(self.label_126, 0, 3, 2, 1)
        self.label_124 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_124.setFont(font)
        self.label_124.setObjectName(_fromUtf8("label_124"))
        self.gridLayout_45.addWidget(self.label_124, 0, 2, 2, 1)
        self.label_133 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_133.setFont(font)
        self.label_133.setObjectName(_fromUtf8("label_133"))
        self.gridLayout_45.addWidget(self.label_133, 8, 0, 1, 2)
        self.groupBoxDis_2 = QtGui.QGroupBox(self.dockWidgetContents)
        self.groupBoxDis_2.setEnabled(False)
        self.groupBoxDis_2.setObjectName(_fromUtf8("groupBoxDis_2"))
        self.verticalLayout_4 = QtGui.QVBoxLayout(self.groupBoxDis_2)
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.label_7 = QtGui.QLabel(self.groupBoxDis_2)
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.verticalLayout_4.addWidget(self.label_7)
        self.gridLayout_45.addWidget(self.groupBoxDis_2, 2, 3, 1, 1)
        self.stackedWidget_2 = QtGui.QStackedWidget(self.dockWidgetContents)
        self.stackedWidget_2.setObjectName(_fromUtf8("stackedWidget_2"))
        self.page1_2 = QtGui.QWidget()
        self.page1_2.setObjectName(_fromUtf8("page1_2"))
        self.gridLayout_35 = QtGui.QGridLayout(self.page1_2)
        self.gridLayout_35.setObjectName(_fromUtf8("gridLayout_35"))
        self.label_57 = QtGui.QLabel(self.page1_2)
        self.label_57.setObjectName(_fromUtf8("label_57"))
        self.gridLayout_35.addWidget(self.label_57, 0, 0, 1, 1)
        self.stackedWidget_2.addWidget(self.page1_2)
        self.page2_2 = QtGui.QWidget()
        self.page2_2.setObjectName(_fromUtf8("page2_2"))
        self.gridLayout_36 = QtGui.QGridLayout(self.page2_2)
        self.gridLayout_36.setObjectName(_fromUtf8("gridLayout_36"))
        self.label_58 = QtGui.QLabel(self.page2_2)
        self.label_58.setObjectName(_fromUtf8("label_58"))
        self.gridLayout_36.addWidget(self.label_58, 0, 0, 1, 1)
        self.stackedWidget_2.addWidget(self.page2_2)
        self.gridLayout_45.addWidget(self.stackedWidget_2, 5, 2, 1, 1)
        self.stackedWidgetDis_2 = QtGui.QStackedWidget(self.dockWidgetContents)
        self.stackedWidgetDis_2.setEnabled(False)
        self.stackedWidgetDis_2.setObjectName(_fromUtf8("stackedWidgetDis_2"))
        self.page1Dis_2 = QtGui.QWidget()
        self.page1Dis_2.setObjectName(_fromUtf8("page1Dis_2"))
        self.gridLayout_37 = QtGui.QGridLayout(self.page1Dis_2)
        self.gridLayout_37.setObjectName(_fromUtf8("gridLayout_37"))
        self.label_113 = QtGui.QLabel(self.page1Dis_2)
        self.label_113.setObjectName(_fromUtf8("label_113"))
        self.gridLayout_37.addWidget(self.label_113, 0, 0, 1, 1)
        self.stackedWidgetDis_2.addWidget(self.page1Dis_2)
        self.page2Dis_2 = QtGui.QWidget()
        self.page2Dis_2.setObjectName(_fromUtf8("page2Dis_2"))
        self.gridLayout_38 = QtGui.QGridLayout(self.page2Dis_2)
        self.gridLayout_38.setObjectName(_fromUtf8("gridLayout_38"))
        self.label_114 = QtGui.QLabel(self.page2Dis_2)
        self.label_114.setObjectName(_fromUtf8("label_114"))
        self.gridLayout_38.addWidget(self.label_114, 0, 0, 1, 1)
        self.stackedWidgetDis_2.addWidget(self.page2Dis_2)
        self.gridLayout_45.addWidget(self.stackedWidgetDis_2, 5, 3, 1, 1)
        self.label_131 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_131.setFont(font)
        self.label_131.setObjectName(_fromUtf8("label_131"))
        self.gridLayout_45.addWidget(self.label_131, 6, 0, 1, 1)
        self.frame_2 = QtGui.QFrame(self.dockWidgetContents)
        self.frame_2.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_2.setObjectName(_fromUtf8("frame_2"))
        self.gridLayout_43 = QtGui.QGridLayout(self.frame_2)
        self.gridLayout_43.setObjectName(_fromUtf8("gridLayout_43"))
        self.label_9 = QtGui.QLabel(self.frame_2)
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.gridLayout_43.addWidget(self.label_9, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.frame_2, 6, 2, 1, 1)
        self.frameDis_2 = QtGui.QFrame(self.dockWidgetContents)
        self.frameDis_2.setEnabled(False)
        self.frameDis_2.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frameDis_2.setFrameShadow(QtGui.QFrame.Raised)
        self.frameDis_2.setObjectName(_fromUtf8("frameDis_2"))
        self.gridLayout_40 = QtGui.QGridLayout(self.frameDis_2)
        self.gridLayout_40.setObjectName(_fromUtf8("gridLayout_40"))
        self.label_8 = QtGui.QLabel(self.frameDis_2)
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.gridLayout_40.addWidget(self.label_8, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.frameDis_2, 6, 3, 1, 1)
        self.label_132 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_132.setFont(font)
        self.label_132.setObjectName(_fromUtf8("label_132"))
        self.gridLayout_45.addWidget(self.label_132, 7, 0, 1, 2)
        self.groupBox_2 = QtGui.QGroupBox(self.dockWidgetContents)
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.gridLayout_7 = QtGui.QGridLayout(self.groupBox_2)
        self.gridLayout_7.setObjectName(_fromUtf8("gridLayout_7"))
        self.label_10 = QtGui.QLabel(self.groupBox_2)
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.gridLayout_7.addWidget(self.label_10, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.groupBox_2, 2, 2, 1, 1)
        self.mdiAreaDis_2 = QtGui.QMdiArea(self.dockWidgetContents)
        self.mdiAreaDis_2.setEnabled(False)
        self.mdiAreaDis_2.setObjectName(_fromUtf8("mdiAreaDis_2"))
        self.subwindow1Dis_2 = QtGui.QWidget()
        self.subwindow1Dis_2.setObjectName(_fromUtf8("subwindow1Dis_2"))
        self.verticalLayout_9 = QtGui.QVBoxLayout(self.subwindow1Dis_2)
        self.verticalLayout_9.setObjectName(_fromUtf8("verticalLayout_9"))
        self.label_111 = QtGui.QLabel(self.subwindow1Dis_2)
        self.label_111.setObjectName(_fromUtf8("label_111"))
        self.verticalLayout_9.addWidget(self.label_111)
        self.subwindow2Dis_2 = QtGui.QWidget()
        self.subwindow2Dis_2.setObjectName(_fromUtf8("subwindow2Dis_2"))
        self.verticalLayout_10 = QtGui.QVBoxLayout(self.subwindow2Dis_2)
        self.verticalLayout_10.setObjectName(_fromUtf8("verticalLayout_10"))
        self.label_112 = QtGui.QLabel(self.subwindow2Dis_2)
        self.label_112.setObjectName(_fromUtf8("label_112"))
        self.verticalLayout_10.addWidget(self.label_112)
        self.gridLayout_45.addWidget(self.mdiAreaDis_2, 8, 3, 1, 1)
        self.label_127 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_127.setFont(font)
        self.label_127.setObjectName(_fromUtf8("label_127"))
        self.gridLayout_45.addWidget(self.label_127, 2, 0, 1, 2)
        self.widget_2 = QtGui.QWidget(self.dockWidgetContents)
        self.widget_2.setObjectName(_fromUtf8("widget_2"))
        self.gridLayout_39 = QtGui.QGridLayout(self.widget_2)
        self.gridLayout_39.setObjectName(_fromUtf8("gridLayout_39"))
        self.label_59 = QtGui.QLabel(self.widget_2)
        self.label_59.setObjectName(_fromUtf8("label_59"))
        self.gridLayout_39.addWidget(self.label_59, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.widget_2, 7, 2, 1, 1)
        self.widgetDis_2 = QtGui.QWidget(self.dockWidgetContents)
        self.widgetDis_2.setEnabled(False)
        self.widgetDis_2.setObjectName(_fromUtf8("widgetDis_2"))
        self.gridLayout_44 = QtGui.QGridLayout(self.widgetDis_2)
        self.gridLayout_44.setObjectName(_fromUtf8("gridLayout_44"))
        self.label_125 = QtGui.QLabel(self.widgetDis_2)
        self.label_125.setObjectName(_fromUtf8("label_125"))
        self.gridLayout_44.addWidget(self.label_125, 0, 0, 1, 1)
        self.gridLayout_45.addWidget(self.widgetDis_2, 7, 3, 1, 1)
        self.mdiArea_2 = QtGui.QMdiArea(self.dockWidgetContents)
        self.mdiArea_2.setObjectName(_fromUtf8("mdiArea_2"))
        self.subwindow1_2 = QtGui.QWidget()
        self.subwindow1_2.setObjectName(_fromUtf8("subwindow1_2"))
        self.verticalLayout_11 = QtGui.QVBoxLayout(self.subwindow1_2)
        self.verticalLayout_11.setObjectName(_fromUtf8("verticalLayout_11"))
        self.label_29 = QtGui.QLabel(self.subwindow1_2)
        self.label_29.setObjectName(_fromUtf8("label_29"))
        self.verticalLayout_11.addWidget(self.label_29)
        self.subwindow2_2 = QtGui.QWidget()
        self.subwindow2_2.setObjectName(_fromUtf8("subwindow2_2"))
        self.verticalLayout_12 = QtGui.QVBoxLayout(self.subwindow2_2)
        self.verticalLayout_12.setObjectName(_fromUtf8("verticalLayout_12"))
        self.label_56 = QtGui.QLabel(self.subwindow2_2)
        self.label_56.setObjectName(_fromUtf8("label_56"))
        self.verticalLayout_12.addWidget(self.label_56)
        self.gridLayout_45.addWidget(self.mdiArea_2, 8, 2, 1, 1)
        self.label_128 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_128.setFont(font)
        self.label_128.setObjectName(_fromUtf8("label_128"))
        self.gridLayout_45.addWidget(self.label_128, 3, 0, 1, 2)
        self.scrollArea_2 = QtGui.QScrollArea(self.dockWidgetContents)
        self.scrollArea_2.setWidgetResizable(True)
        self.scrollArea_2.setObjectName(_fromUtf8("scrollArea_2"))
        self.scrollAreaWidgetContents_2 = QtGui.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 181, 246))
        self.scrollAreaWidgetContents_2.setObjectName(_fromUtf8("scrollAreaWidgetContents_2"))
        self.verticalLayout_14 = QtGui.QVBoxLayout(self.scrollAreaWidgetContents_2)
        self.verticalLayout_14.setObjectName(_fromUtf8("verticalLayout_14"))
        self.label_70 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_70.setObjectName(_fromUtf8("label_70"))
        self.verticalLayout_14.addWidget(self.label_70)
        self.label_71 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_71.setObjectName(_fromUtf8("label_71"))
        self.verticalLayout_14.addWidget(self.label_71)
        self.label_75 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_75.setObjectName(_fromUtf8("label_75"))
        self.verticalLayout_14.addWidget(self.label_75)
        self.label_76 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_76.setObjectName(_fromUtf8("label_76"))
        self.verticalLayout_14.addWidget(self.label_76)
        self.label_77 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_77.setObjectName(_fromUtf8("label_77"))
        self.verticalLayout_14.addWidget(self.label_77)
        self.label_78 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_78.setObjectName(_fromUtf8("label_78"))
        self.verticalLayout_14.addWidget(self.label_78)
        self.label_79 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_79.setObjectName(_fromUtf8("label_79"))
        self.verticalLayout_14.addWidget(self.label_79)
        self.label_80 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_80.setObjectName(_fromUtf8("label_80"))
        self.verticalLayout_14.addWidget(self.label_80)
        self.label_81 = QtGui.QLabel(self.scrollAreaWidgetContents_2)
        self.label_81.setObjectName(_fromUtf8("label_81"))
        self.verticalLayout_14.addWidget(self.label_81)
        self.scrollArea_2.setWidget(self.scrollAreaWidgetContents_2)
        self.gridLayout_45.addWidget(self.scrollArea_2, 3, 2, 1, 1)
        self.scrollAreaDis_2 = QtGui.QScrollArea(self.dockWidgetContents)
        self.scrollAreaDis_2.setEnabled(False)
        self.scrollAreaDis_2.setWidgetResizable(True)
        self.scrollAreaDis_2.setObjectName(_fromUtf8("scrollAreaDis_2"))
        self.scrollAreaWidgetContentsDis_2 = QtGui.QWidget()
        self.scrollAreaWidgetContentsDis_2.setGeometry(QtCore.QRect(0, 0, 181, 246))
        self.scrollAreaWidgetContentsDis_2.setObjectName(_fromUtf8("scrollAreaWidgetContentsDis_2"))
        self.verticalLayout_13 = QtGui.QVBoxLayout(self.scrollAreaWidgetContentsDis_2)
        self.verticalLayout_13.setObjectName(_fromUtf8("verticalLayout_13"))
        self.label_115 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_115.setObjectName(_fromUtf8("label_115"))
        self.verticalLayout_13.addWidget(self.label_115)
        self.label_116 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_116.setObjectName(_fromUtf8("label_116"))
        self.verticalLayout_13.addWidget(self.label_116)
        self.label_117 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_117.setObjectName(_fromUtf8("label_117"))
        self.verticalLayout_13.addWidget(self.label_117)
        self.label_118 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_118.setObjectName(_fromUtf8("label_118"))
        self.verticalLayout_13.addWidget(self.label_118)
        self.label_119 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_119.setObjectName(_fromUtf8("label_119"))
        self.verticalLayout_13.addWidget(self.label_119)
        self.label_120 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_120.setObjectName(_fromUtf8("label_120"))
        self.verticalLayout_13.addWidget(self.label_120)
        self.label_121 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_121.setObjectName(_fromUtf8("label_121"))
        self.verticalLayout_13.addWidget(self.label_121)
        self.label_122 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_122.setObjectName(_fromUtf8("label_122"))
        self.verticalLayout_13.addWidget(self.label_122)
        self.label_123 = QtGui.QLabel(self.scrollAreaWidgetContentsDis_2)
        self.label_123.setObjectName(_fromUtf8("label_123"))
        self.verticalLayout_13.addWidget(self.label_123)
        self.scrollAreaDis_2.setWidget(self.scrollAreaWidgetContentsDis_2)
        self.gridLayout_45.addWidget(self.scrollAreaDis_2, 3, 3, 1, 1)
        self.label_129 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_129.setFont(font)
        self.label_129.setObjectName(_fromUtf8("label_129"))
        self.gridLayout_45.addWidget(self.label_129, 4, 0, 1, 2)
        self.toolBox_2 = QtGui.QToolBox(self.dockWidgetContents)
        self.toolBox_2.setObjectName(_fromUtf8("toolBox_2"))
        self.page_3 = QtGui.QWidget()
        self.page_3.setGeometry(QtCore.QRect(0, 0, 196, 73))
        self.page_3.setObjectName(_fromUtf8("page_3"))
        self.gridLayout_41 = QtGui.QGridLayout(self.page_3)
        self.gridLayout_41.setObjectName(_fromUtf8("gridLayout_41"))
        self.label_60 = QtGui.QLabel(self.page_3)
        self.label_60.setObjectName(_fromUtf8("label_60"))
        self.gridLayout_41.addWidget(self.label_60, 2, 0, 1, 1)
        self.toolBox_2.addItem(self.page_3, _fromUtf8(""))
        self.page_8 = QtGui.QWidget()
        self.page_8.setGeometry(QtCore.QRect(0, 0, 163, 38))
        self.page_8.setObjectName(_fromUtf8("page_8"))
        self.gridLayout_42 = QtGui.QGridLayout(self.page_8)
        self.gridLayout_42.setObjectName(_fromUtf8("gridLayout_42"))
        self.label_61 = QtGui.QLabel(self.page_8)
        self.label_61.setObjectName(_fromUtf8("label_61"))
        self.gridLayout_42.addWidget(self.label_61, 0, 0, 1, 1)
        self.toolBox_2.addItem(self.page_8, _fromUtf8(""))
        self.gridLayout_45.addWidget(self.toolBox_2, 4, 2, 1, 1)
        self.toolBoxDis_2 = QtGui.QToolBox(self.dockWidgetContents)
        self.toolBoxDis_2.setEnabled(False)
        self.toolBoxDis_2.setObjectName(_fromUtf8("toolBoxDis_2"))
        self.page_6 = QtGui.QWidget()
        self.page_6.setGeometry(QtCore.QRect(0, 0, 196, 73))
        self.page_6.setObjectName(_fromUtf8("page_6"))
        self.gridLayout_29 = QtGui.QGridLayout(self.page_6)
        self.gridLayout_29.setObjectName(_fromUtf8("gridLayout_29"))
        self.label_109 = QtGui.QLabel(self.page_6)
        self.label_109.setObjectName(_fromUtf8("label_109"))
        self.gridLayout_29.addWidget(self.label_109, 2, 0, 1, 1)
        self.toolBoxDis_2.addItem(self.page_6, _fromUtf8(""))
        self.page_7 = QtGui.QWidget()
        self.page_7.setGeometry(QtCore.QRect(0, 0, 163, 38))
        self.page_7.setObjectName(_fromUtf8("page_7"))
        self.gridLayout_34 = QtGui.QGridLayout(self.page_7)
        self.gridLayout_34.setObjectName(_fromUtf8("gridLayout_34"))
        self.label_110 = QtGui.QLabel(self.page_7)
        self.label_110.setObjectName(_fromUtf8("label_110"))
        self.gridLayout_34.addWidget(self.label_110, 0, 0, 1, 1)
        self.toolBoxDis_2.addItem(self.page_7, _fromUtf8(""))
        self.gridLayout_45.addWidget(self.toolBoxDis_2, 4, 3, 1, 1)
        self.label_130 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_130.setFont(font)
        self.label_130.setObjectName(_fromUtf8("label_130"))
        self.gridLayout_45.addWidget(self.label_130, 5, 0, 1, 2)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        self.stackedWidget_2.setCurrentIndex(1)
        self.stackedWidgetDis_2.setCurrentIndex(1)
        self.toolBox_2.setCurrentIndex(0)
        self.toolBoxDis_2.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(_translate("DockWidget", "Containers - No Tabs", None))
        self.label_126.setText(_translate("DockWidget", "Disabled", None))
        self.label_124.setText(_translate("DockWidget", "Enabled", None))
        self.label_133.setText(_translate("DockWidget", "MDI Area", None))
        self.groupBoxDis_2.setTitle(_translate("DockWidget", "GroupBox", None))
        self.label_7.setText(_translate("DockWidget", "Inside GroupBox", None))
        self.stackedWidget_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.stackedWidget_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.stackedWidget_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_57.setText(_translate("DockWidget", "Inside Stacked Page 1", None))
        self.label_58.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_58.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_58.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_58.setText(_translate("DockWidget", "Inside Stacked Page 2", None))
        self.stackedWidgetDis_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.stackedWidgetDis_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.stackedWidgetDis_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_113.setText(_translate("DockWidget", "Inside Stacked Page 1", None))
        self.label_114.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_114.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_114.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_114.setText(_translate("DockWidget", "Inside Stacked Page 2", None))
        self.label_131.setText(_translate("DockWidget", "Frame", None))
        self.frame_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.frame_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.frame_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_9.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_9.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_9.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_9.setText(_translate("DockWidget", "Inside Frame", None))
        self.frameDis_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.frameDis_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.frameDis_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_8.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_8.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_8.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_8.setText(_translate("DockWidget", "Inside Frame", None))
        self.label_132.setText(_translate("DockWidget", "Widget", None))
        self.groupBox_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.groupBox_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.groupBox_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.groupBox_2.setTitle(_translate("DockWidget", "GroupBox", None))
        self.label_10.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_10.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_10.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_10.setText(_translate("DockWidget", "Inside GroupBox", None))
        self.subwindow1Dis_2.setWindowTitle(_translate("DockWidget", "Subwindow", None))
        self.label_111.setText(_translate("DockWidget", "Inside MDI Area 1", None))
        self.subwindow2Dis_2.setWindowTitle(_translate("DockWidget", "Subwindow", None))
        self.label_112.setText(_translate("DockWidget", "Inside MDI Area 2 ", None))
        self.label_127.setText(_translate("DockWidget", "GroupBox", None))
        self.widget_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.widget_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.widget_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_59.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_59.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_59.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_59.setText(_translate("DockWidget", "Inside Widget", None))
        self.widgetDis_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.widgetDis_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.widgetDis_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_125.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_125.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_125.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_125.setText(_translate("DockWidget", "Inside Widget", None))
        self.subwindow1_2.setWindowTitle(_translate("DockWidget", "Subwindow", None))
        self.label_29.setText(_translate("DockWidget", "Inside MDI Area 1", None))
        self.subwindow2_2.setWindowTitle(_translate("DockWidget", "Subwindow", None))
        self.label_56.setText(_translate("DockWidget", "Inside MDI Area 2 ", None))
        self.label_128.setText(_translate("DockWidget", "ScroolArea", None))
        self.scrollArea_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.scrollArea_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.scrollArea_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_70.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_70.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_70.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_70.setText(_translate("DockWidget", "Inside ScroolArea", None))
        self.label_71.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_71.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_71.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_71.setText(_translate("DockWidget", "ScroolArea ", None))
        self.label_75.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_75.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_75.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_75.setText(_translate("DockWidget", "Inside ScroolArea ", None))
        self.label_76.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_76.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_76.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_76.setText(_translate("DockWidget", "ScroolArea", None))
        self.label_77.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_77.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_77.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_77.setText(_translate("DockWidget", "Inside ScroolArea", None))
        self.label_78.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_78.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_78.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_78.setText(_translate("DockWidget", "ScroolArea", None))
        self.label_79.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_79.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_79.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_79.setText(_translate("DockWidget", "Inside ScroolArea", None))
        self.label_80.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_80.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_80.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_80.setText(_translate("DockWidget", "ScroolArea", None))
        self.label_81.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_81.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_81.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_81.setText(_translate("DockWidget", "Inside ScroolArea", None))
        self.scrollAreaDis_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.scrollAreaDis_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.scrollAreaDis_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_115.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_115.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_115.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_115.setText(_translate("DockWidget", "Inside ScroolArea", None))
        self.label_116.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_116.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_116.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_116.setText(_translate("DockWidget", "ScroolArea ", None))
        self.label_117.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_117.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_117.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_117.setText(_translate("DockWidget", "Inside ScroolArea ", None))
        self.label_118.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_118.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_118.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_118.setText(_translate("DockWidget", "ScroolArea", None))
        self.label_119.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_119.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_119.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_119.setText(_translate("DockWidget", "Inside ScroolArea", None))
        self.label_120.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_120.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_120.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_120.setText(_translate("DockWidget", "ScroolArea", None))
        self.label_121.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_121.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_121.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_121.setText(_translate("DockWidget", "Inside ScroolArea", None))
        self.label_122.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_122.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_122.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_122.setText(_translate("DockWidget", "ScroolArea", None))
        self.label_123.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_123.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_123.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_123.setText(_translate("DockWidget", "Inside ScroolArea", None))
        self.label_129.setText(_translate("DockWidget", "ToolBox", None))
        self.toolBox_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.toolBox_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.toolBox_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_60.setText(_translate("DockWidget", "Inside ToolBox Page 1", None))
        self.toolBox_2.setItemText(self.toolBox_2.indexOf(self.page_3), _translate("DockWidget", "Page 1", None))
        self.label_61.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_61.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_61.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_61.setText(_translate("DockWidget", "Inside ToolBox Page 2", None))
        self.toolBox_2.setItemText(self.toolBox_2.indexOf(self.page_8), _translate("DockWidget", "Page 2", None))
        self.toolBoxDis_2.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.toolBoxDis_2.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.toolBoxDis_2.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_109.setText(_translate("DockWidget", "Inside ToolBox Page 1", None))
        self.toolBoxDis_2.setItemText(self.toolBoxDis_2.indexOf(self.page_6), _translate("DockWidget", "Page 1", None))
        self.label_110.setToolTip(_translate("DockWidget", "This is a tool tip", None))
        self.label_110.setStatusTip(_translate("DockWidget", "This is a status tip", None))
        self.label_110.setWhatsThis(_translate("DockWidget", "This is \"what is this\"", None))
        self.label_110.setText(_translate("DockWidget", "Inside ToolBox Page 2", None))
        self.toolBoxDis_2.setItemText(self.toolBoxDis_2.indexOf(self.page_7), _translate("DockWidget", "Page 2", None))
        self.label_130.setText(_translate("DockWidget", "Stacked", None))




# -*- coding: utf-8 -*-
"""Script to process QRC files (convert .qrc to _rc.py and .rcc).

The script will attempt to compile the qrc file using the following tools:

    - pyrcc4 for PyQt4 and PyQtGraph (Python)
    - pyrcc5 for PyQt5 and QtPy (Python)
    - pyside-rcc for PySide (Python)
    - pyside2-rcc for PySide2 (Python)
    - rcc for Qt4 and Qt5 (C++)

Delete the compiled files that you don't want to use manually after
running this script.

Links to understand those tools:

    - pyrcc4: http://pyqt.sourceforge.net/Docs/PyQt4/resources.html#pyrcc4
    - pyrcc5: http://pyqt.sourceforge.net/Docs/PyQt5/resources.html#pyrcc5
    - pyside-rcc: https://www.mankier.com/1/pyside-rcc
    - pyside2-rcc: https://doc.qt.io/qtforpython/overviews/resources.html (Documentation Incomplete)
    - rcc on Qt4: http://doc.qt.io/archives/qt-4.8/rcc.html
    - rcc on Qt5: http://doc.qt.io/qt-5/rcc.html

"""

from __future__ import absolute_import, print_function

import argparse
import glob
import os
import sys
from subprocess import call


def main(arguments):
    """Process QRC files."""
    parser = argparse.ArgumentParser(description=__doc__,
                                     formatter_class=argparse.RawDescriptionHelpFormatter)
    parser.add_argument('--qrc_dir',
                        default='../qdarkstyle',
                        type=str,
                        help="QRC file directory, relative to current directory.",)
    parser.add_argument('--create',
                        default='all',
                        choices=['pyqt', 'pyqt5', 'pyside', 'pyside2', 'qtpy', 'pyqtgraph', 'qt', 'qt5', 'all'],
                        type=str,
                        help="Choose which one would be generated.")

    args = parser.parse_args(arguments)

    print('Changing directory to: ', args.qrc_dir)
    os.chdir(args.qrc_dir)

    print('Converting .qrc to _rc.py and/or .rcc ...')

    for qrc_file in glob.glob('*.qrc'):
        # get name without extension
        filename = os.path.splitext(qrc_file)[0]

        print(filename, '...')
        ext = '_rc.py'
        ext_c = '.rcc'

        # creating names
        py_file_pyqt5 = 'pyqt5_' + filename + ext
        py_file_pyqt = 'pyqt_' + filename + ext
        py_file_pyside = 'pyside_' + filename + ext
        py_file_pyside2 = 'pyside2_' + filename + ext
        py_file_qtpy = 'qtpy_' + filename + ext
        py_file_pyqtgraph = 'pyqtgraph_' + filename + ext

        # calling external commands
        if args.create in ['pyqt', 'pyqtgraph', 'all']:
            print("Compiling for PyQt4 ...")
            try:
                call(['pyrcc4', '-py3', qrc_file, '-o', py_file_pyqt])
            except FileNotFoundError:
                print("You must install pyrcc4")

        if args.create in ['pyqt5', 'qtpy', 'all']:
            print("Compiling for PyQt5 ...")
            try:
                call(['pyrcc5', qrc_file, '-o', py_file_pyqt5])
            except FileNotFoundError:
                print("You must install pyrcc5")

        if args.create in ['pyside', 'all']:
            print("Compiling for PySide ...")
            try:    
                call(['pyside-rcc', '-py3', qrc_file, '-o', py_file_pyside])
            except FileNotFoundError:
                print("You must install pyside-rcc")

        if args.create in ['pyside2', 'all']:
            print("Compiling for PySide 2...")
            try:
                call(['pyside2-rcc', '-py3', qrc_file, '-o', py_file_pyside2])
            except FileNotFoundError:
                print("You must install pyside2-rcc")

        if args.create in ['qtpy', 'all']:
            print("Compiling for QtPy ...")
            # special case - qtpy - syntax is PyQt5
            with open(py_file_pyqt5, 'r') as file:
                filedata = file.read()
            # replace the target string
            filedata = filedata.replace('from PyQt5', 'from qtpy')
            with open(py_file_qtpy, 'w+') as file:
                # write the file out again
                file.write(filedata)

        if args.create in ['pyqtgraph', 'all']:
            print("Compiling for PyQtGraph ...")
            # special case - pyqtgraph - syntax is PyQt4
            with open(py_file_pyqt, 'r') as file:
                filedata = file.read()
            # replace the target string
            filedata = filedata.replace('from PyQt4', 'from pyqtgraph.Qt')
            with open(py_file_pyqtgraph, 'w+') as file:
                # write the file out again
                file.write(filedata)


if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_views.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from pyqtgraph.Qt import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName(_fromUtf8("DockWidget"))
        DockWidget.resize(266, 387)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.label_70 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_70.setFont(font)
        self.label_70.setObjectName(_fromUtf8("label_70"))
        self.gridLayout.addWidget(self.label_70, 0, 1, 1, 1)
        self.label_80 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_80.setFont(font)
        self.label_80.setObjectName(_fromUtf8("label_80"))
        self.gridLayout.addWidget(self.label_80, 0, 2, 1, 1)
        self.label_27 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_27.setFont(font)
        self.label_27.setObjectName(_fromUtf8("label_27"))
        self.gridLayout.addWidget(self.label_27, 1, 0, 1, 1)
        self.listView = QtGui.QListView(self.dockWidgetContents)
        self.listView.setObjectName(_fromUtf8("listView"))
        self.gridLayout.addWidget(self.listView, 1, 1, 1, 1)
        self.listViewDis = QtGui.QListView(self.dockWidgetContents)
        self.listViewDis.setEnabled(False)
        self.listViewDis.setObjectName(_fromUtf8("listViewDis"))
        self.gridLayout.addWidget(self.listViewDis, 1, 2, 1, 1)
        self.label_59 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_59.setFont(font)
        self.label_59.setObjectName(_fromUtf8("label_59"))
        self.gridLayout.addWidget(self.label_59, 2, 0, 1, 1)
        self.treeView = QtGui.QTreeView(self.dockWidgetContents)
        self.treeView.setObjectName(_fromUtf8("treeView"))
        self.gridLayout.addWidget(self.treeView, 2, 1, 1, 1)
        self.treeViewDis = QtGui.QTreeView(self.dockWidgetContents)
        self.treeViewDis.setEnabled(False)
        self.treeViewDis.setObjectName(_fromUtf8("treeViewDis"))
        self.gridLayout.addWidget(self.treeViewDis, 2, 2, 1, 1)
        self.label_60 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_60.setFont(font)
        self.label_60.setObjectName(_fromUtf8("label_60"))
        self.gridLayout.addWidget(self.label_60, 3, 0, 1, 1)
        self.tableView = QtGui.QTableView(self.dockWidgetContents)
        self.tableView.setObjectName(_fromUtf8("tableView"))
        self.gridLayout.addWidget(self.tableView, 3, 1, 1, 1)
        self.tableViewDis = QtGui.QTableView(self.dockWidgetContents)
        self.tableViewDis.setEnabled(False)
        self.tableViewDis.setObjectName(_fromUtf8("tableViewDis"))
        self.gridLayout.addWidget(self.tableViewDis, 3, 2, 1, 1)
        self.label_61 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_61.setFont(font)
        self.label_61.setObjectName(_fromUtf8("label_61"))
        self.gridLayout.addWidget(self.label_61, 4, 0, 1, 1)
        self.columnView = QtGui.QColumnView(self.dockWidgetContents)
        self.columnView.setObjectName(_fromUtf8("columnView"))
        self.gridLayout.addWidget(self.columnView, 4, 1, 1, 1)
        self.columnViewDis = QtGui.QColumnView(self.dockWidgetContents)
        self.columnViewDis.setEnabled(False)
        self.columnViewDis.setObjectName(_fromUtf8("columnViewDis"))
        self.gridLayout.addWidget(self.columnViewDis, 4, 2, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(_translate("DockWidget", "Views", None))
        self.label_70.setText(_translate("DockWidget", "Enabled", None))
        self.label_80.setText(_translate("DockWidget", "Disabled", None))
        self.label_27.setText(_translate("DockWidget", "ListView", None))
        self.label_59.setText(_translate("DockWidget", "TreeView", None))
        self.label_60.setText(_translate("DockWidget", "TableView", None))
        self.label_61.setText(_translate("DockWidget", "ColunmView", None))




#!/usr/bin/env python
# -*- coding: utf-8 -*-

from qdarkstyle import qt_bindings, qt_abstractions, information, __version__
import qdarkstyle
import argparse
import sys

from os.path import abspath, dirname
sys.path.insert(0, abspath(dirname(abspath(__file__)) + '/..'))


def print_list_md(info):
    """Print a list of information, line by line."""
    for item in info:
        print('  - ' + item)


def main():
    """Execute QDarkStyle example."""
    parser = argparse.ArgumentParser(description=__doc__,
                                     formatter_class=argparse.RawDescriptionHelpFormatter)
    parser.add_argument('-i', '--information', action='store_true',
                        help="Show information about environment (important for bug report)")
    parser.add_argument('-b', '--bindings', action='store_true',
                        help="Show available bindings for Qt")
    parser.add_argument('-a', '--abstractions', action='store_true',
                        help="Show available abstraction layers for Qt bindings")
    # parser.add_argument('-e', '--example', action='store_true',
    #                     help="Show qdarkstyle example, subcommand.")
    parser.add_argument('-v', '--version', action='store_true',
                        help="Show qdarkstyle version")
    parser.add_argument('--all', action='store_true',
                        help="Show all information options at once")

    # parsing arguments from command line
    args = parser.parse_args()

    parser.print_help()

    if args.information or args.all:
        info = information()
        print('\nInformation about your current environment setup:')
        print_list_md(info)

    if args.bindings or args.all:
        info = qt_bindings()
        print('\nQt bindings available:')
        print_list_md(info)

    if args.abstractions or args.all:
        info = qt_abstractions()
        print('\nQt abstraction layers available:')
        print_list_md(info)

    if args.version:
        info = __version__
        print('\nVersion: %s' % info)

    # if args.example:
    #     example.main()


if __name__ == "__main__":
    sys.exit(main())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_inputs_no_fields.ui'
#
# Created: Thu Dec 13 17:14:06 2018
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(402, 405)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName("gridLayout")
        self.dial = QtGui.QDial(self.dockWidgetContents)
        self.dial.setMinimumSize(QtCore.QSize(0, 0))
        self.dial.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dial.setProperty("value", 50)
        self.dial.setObjectName("dial")
        self.gridLayout.addWidget(self.dial, 2, 1, 1, 1)
        self.label_25 = QtGui.QLabel(self.dockWidgetContents)
        self.label_25.setMinimumSize(QtCore.QSize(0, 0))
        self.label_25.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_25.setFont(font)
        self.label_25.setObjectName("label_25")
        self.gridLayout.addWidget(self.label_25, 7, 0, 1, 1)
        self.horizontalScrollBarDis = QtGui.QScrollBar(self.dockWidgetContents)
        self.horizontalScrollBarDis.setEnabled(False)
        self.horizontalScrollBarDis.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalScrollBarDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalScrollBarDis.setProperty("value", 50)
        self.horizontalScrollBarDis.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalScrollBarDis.setObjectName("horizontalScrollBarDis")
        self.gridLayout.addWidget(self.horizontalScrollBarDis, 3, 2, 1, 1)
        self.verticalSlider = QtGui.QSlider(self.dockWidgetContents)
        self.verticalSlider.setMinimumSize(QtCore.QSize(0, 70))
        self.verticalSlider.setMaximumSize(QtCore.QSize(16777215, 70))
        self.verticalSlider.setProperty("value", 50)
        self.verticalSlider.setOrientation(QtCore.Qt.Vertical)
        self.verticalSlider.setObjectName("verticalSlider")
        self.gridLayout.addWidget(self.verticalSlider, 7, 1, 1, 1)
        self.label_24 = QtGui.QLabel(self.dockWidgetContents)
        self.label_24.setMinimumSize(QtCore.QSize(0, 0))
        self.label_24.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_24.setFont(font)
        self.label_24.setObjectName("label_24")
        self.gridLayout.addWidget(self.label_24, 4, 0, 1, 1)
        self.horizontalSlider = QtGui.QSlider(self.dockWidgetContents)
        self.horizontalSlider.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalSlider.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalSlider.setProperty("value", 50)
        self.horizontalSlider.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider.setObjectName("horizontalSlider")
        self.gridLayout.addWidget(self.horizontalSlider, 4, 1, 2, 1)
        self.horizontalSliderDis = QtGui.QSlider(self.dockWidgetContents)
        self.horizontalSliderDis.setEnabled(False)
        self.horizontalSliderDis.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalSliderDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalSliderDis.setProperty("value", 50)
        self.horizontalSliderDis.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSliderDis.setObjectName("horizontalSliderDis")
        self.gridLayout.addWidget(self.horizontalSliderDis, 4, 2, 1, 1)
        self.label_23 = QtGui.QLabel(self.dockWidgetContents)
        self.label_23.setMinimumSize(QtCore.QSize(0, 0))
        self.label_23.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_23.setFont(font)
        self.label_23.setObjectName("label_23")
        self.gridLayout.addWidget(self.label_23, 6, 0, 1, 1)
        self.label_2 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 2, 1, 1)
        self.verticalScrollBarDis = QtGui.QScrollBar(self.dockWidgetContents)
        self.verticalScrollBarDis.setEnabled(False)
        self.verticalScrollBarDis.setMinimumSize(QtCore.QSize(0, 70))
        self.verticalScrollBarDis.setMaximumSize(QtCore.QSize(16777215, 70))
        self.verticalScrollBarDis.setProperty("value", 50)
        self.verticalScrollBarDis.setOrientation(QtCore.Qt.Vertical)
        self.verticalScrollBarDis.setObjectName("verticalScrollBarDis")
        self.gridLayout.addWidget(self.verticalScrollBarDis, 5, 2, 2, 1)
        self.label_21 = QtGui.QLabel(self.dockWidgetContents)
        self.label_21.setMinimumSize(QtCore.QSize(0, 0))
        self.label_21.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_21.setFont(font)
        self.label_21.setObjectName("label_21")
        self.gridLayout.addWidget(self.label_21, 2, 0, 1, 1)
        spacerItem = QtGui.QSpacerItem(20, 0, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem, 8, 0, 1, 1)
        self.verticalScrollBar = QtGui.QScrollBar(self.dockWidgetContents)
        self.verticalScrollBar.setMinimumSize(QtCore.QSize(0, 70))
        self.verticalScrollBar.setMaximumSize(QtCore.QSize(16777215, 70))
        self.verticalScrollBar.setProperty("value", 50)
        self.verticalScrollBar.setOrientation(QtCore.Qt.Vertical)
        self.verticalScrollBar.setObjectName("verticalScrollBar")
        self.gridLayout.addWidget(self.verticalScrollBar, 6, 1, 1, 1)
        self.comboBoxDis = QtGui.QComboBox(self.dockWidgetContents)
        self.comboBoxDis.setEnabled(False)
        self.comboBoxDis.setMinimumSize(QtCore.QSize(0, 0))
        self.comboBoxDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.comboBoxDis.setObjectName("comboBoxDis")
        self.comboBoxDis.addItem("")
        self.comboBoxDis.addItem("")
        self.comboBoxDis.addItem("")
        self.gridLayout.addWidget(self.comboBoxDis, 1, 2, 1, 1)
        self.horizontalScrollBar = QtGui.QScrollBar(self.dockWidgetContents)
        self.horizontalScrollBar.setMinimumSize(QtCore.QSize(0, 0))
        self.horizontalScrollBar.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalScrollBar.setProperty("value", 50)
        self.horizontalScrollBar.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalScrollBar.setObjectName("horizontalScrollBar")
        self.gridLayout.addWidget(self.horizontalScrollBar, 3, 1, 1, 1)
        self.comboBox = QtGui.QComboBox(self.dockWidgetContents)
        self.comboBox.setMinimumSize(QtCore.QSize(0, 0))
        self.comboBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.gridLayout.addWidget(self.comboBox, 1, 1, 1, 1)
        self.label_22 = QtGui.QLabel(self.dockWidgetContents)
        self.label_22.setMinimumSize(QtCore.QSize(0, 0))
        self.label_22.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_22.setFont(font)
        self.label_22.setObjectName("label_22")
        self.gridLayout.addWidget(self.label_22, 3, 0, 1, 1)
        self.label = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 1, 1, 1)
        self.label_50 = QtGui.QLabel(self.dockWidgetContents)
        self.label_50.setAlignment(QtCore.Qt.AlignCenter)
        self.label_50.setObjectName("label_50")
        self.gridLayout.addWidget(self.label_50, 9, 0, 1, 3)
        self.label_11 = QtGui.QLabel(self.dockWidgetContents)
        self.label_11.setMinimumSize(QtCore.QSize(0, 0))
        self.label_11.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.gridLayout.addWidget(self.label_11, 1, 0, 1, 1)
        self.dialDis = QtGui.QDial(self.dockWidgetContents)
        self.dialDis.setEnabled(False)
        self.dialDis.setMinimumSize(QtCore.QSize(0, 0))
        self.dialDis.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.dialDis.setProperty("value", 50)
        self.dialDis.setObjectName("dialDis")
        self.gridLayout.addWidget(self.dialDis, 2, 2, 1, 1)
        self.verticalSliderDis = QtGui.QSlider(self.dockWidgetContents)
        self.verticalSliderDis.setEnabled(False)
        self.verticalSliderDis.setMinimumSize(QtCore.QSize(0, 70))
        self.verticalSliderDis.setMaximumSize(QtCore.QSize(16777215, 70))
        self.verticalSliderDis.setProperty("value", 50)
        self.verticalSliderDis.setOrientation(QtCore.Qt.Vertical)
        self.verticalSliderDis.setObjectName("verticalSliderDis")
        self.gridLayout.addWidget(self.verticalSliderDis, 7, 2, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QObject.connect(self.dial, QtCore.SIGNAL("sliderMoved(int)"), self.dialDis.setValue)
        QtCore.QObject.connect(self.horizontalScrollBar, QtCore.SIGNAL("sliderMoved(int)"), self.horizontalScrollBarDis.setValue)
        QtCore.QObject.connect(self.horizontalSlider, QtCore.SIGNAL("sliderMoved(int)"), self.horizontalSliderDis.setValue)
        QtCore.QObject.connect(self.verticalScrollBar, QtCore.SIGNAL("sliderMoved(int)"), self.verticalScrollBarDis.setValue)
        QtCore.QObject.connect(self.verticalSlider, QtCore.SIGNAL("sliderMoved(int)"), self.verticalSliderDis.setValue)
        QtCore.QObject.connect(self.comboBox, QtCore.SIGNAL("currentIndexChanged(int)"), self.comboBoxDis.setCurrentIndex)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(QtGui.QApplication.translate("DockWidget", "Inputs - No Fields", None, QtGui.QApplication.UnicodeUTF8))
        self.dial.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.dial.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.dial.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_25.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_25.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_25.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_25.setText(QtGui.QApplication.translate("DockWidget", "VerticalSlider", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalScrollBarDis.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalScrollBarDis.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalScrollBarDis.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalSlider.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalSlider.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalSlider.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_24.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_24.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_24.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_24.setText(QtGui.QApplication.translate("DockWidget", "HorizontalSlider", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalSlider.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalSlider.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalSlider.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalSliderDis.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalSliderDis.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalSliderDis.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_23.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_23.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_23.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_23.setText(QtGui.QApplication.translate("DockWidget", "VerticalScroolBar", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DockWidget", "Disabled", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalScrollBarDis.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalScrollBarDis.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalScrollBarDis.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_21.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_21.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_21.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_21.setText(QtGui.QApplication.translate("DockWidget", "Dial", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalScrollBar.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalScrollBar.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalScrollBar.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBoxDis.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBoxDis.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBoxDis.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBoxDis.setItemText(0, QtGui.QApplication.translate("DockWidget", "ComboBox A", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBoxDis.setItemText(1, QtGui.QApplication.translate("DockWidget", "ComboBox B", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBoxDis.setItemText(2, QtGui.QApplication.translate("DockWidget", "ComboBox C", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalScrollBar.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalScrollBar.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.horizontalScrollBar.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox.setItemText(0, QtGui.QApplication.translate("DockWidget", "ComboBox A", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox.setItemText(1, QtGui.QApplication.translate("DockWidget", "ComboBox B", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox.setItemText(2, QtGui.QApplication.translate("DockWidget", "ComboBox C", None, QtGui.QApplication.UnicodeUTF8))
        self.label_22.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_22.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_22.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_22.setText(QtGui.QApplication.translate("DockWidget", "HorizontalScroolBar", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DockWidget", "Enabled", None, QtGui.QApplication.UnicodeUTF8))
        self.label_50.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_50.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_50.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_50.setText(QtGui.QApplication.translate("DockWidget", "Inside DockWidget", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("DockWidget", "ComboBox", None, QtGui.QApplication.UnicodeUTF8))
        self.dialDis.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.dialDis.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.dialDis.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalSliderDis.setToolTip(QtGui.QApplication.translate("DockWidget", "This is a tool tip", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalSliderDis.setStatusTip(QtGui.QApplication.translate("DockWidget", "This is a status tip", None, QtGui.QApplication.UnicodeUTF8))
        self.verticalSliderDis.setWhatsThis(QtGui.QApplication.translate("DockWidget", "This is \"what is this\"", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dw_containers_tabs.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName(_fromUtf8("DockWidget"))
        DockWidget.resize(578, 515)
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.gridLayout_5 = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.label_5 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_5.setFont(font)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.gridLayout_5.addWidget(self.label_5, 0, 0, 1, 1)
        self.label_6 = QtGui.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_6.setFont(font)
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.gridLayout_5.addWidget(self.label_6, 0, 1, 1, 1)
        self.tabWidgetNorth = QtGui.QTabWidget(self.dockWidgetContents)
        self.tabWidgetNorth.setDocumentMode(False)
        self.tabWidgetNorth.setTabsClosable(True)
        self.tabWidgetNorth.setObjectName(_fromUtf8("tabWidgetNorth"))
        self.tab_7 = QtGui.QWidget()
        self.tab_7.setObjectName(_fromUtf8("tab_7"))
        self.gridLayout_8 = QtGui.QGridLayout(self.tab_7)
        self.gridLayout_8.setObjectName(_fromUtf8("gridLayout_8"))
        self.label_52 = QtGui.QLabel(self.tab_7)
        self.label_52.setObjectName(_fromUtf8("label_52"))
        self.gridLayout_8.addWidget(self.label_52, 0, 0, 1, 1)
        self.tabWidgetNorth.addTab(self.tab_7, _fromUtf8(""))
        self.tab_8 = QtGui.QWidget()
        self.tab_8.setObjectName(_fromUtf8("tab_8"))
        self.gridLayout_4 = QtGui.QGridLayout(self.tab_8)
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        self.label_48 = QtGui.QLabel(self.tab_8)
        self.label_48.setObjectName(_fromUtf8("label_48"))
        self.gridLayout_4.addWidget(self.label_48, 0, 0, 1, 1)
        self.tabWidgetNorth.addTab(self.tab_8, _fromUtf8(""))
        self.gridLayout_5.addWidget(self.tabWidgetNorth, 1, 0, 1, 1)
        self.tabWidgetNorth_2 = QtGui.QTabWidget(self.dockWidgetContents)
        self.tabWidgetNorth_2.setEnabled(False)
        self.tabWidgetNorth_2.setDocumentMode(False)
        self.tabWidgetNorth_2.setTabsClosable(True)
        self.tabWidgetNorth_2.setObjectName(_fromUtf8("tabWidgetNorth_2"))
        self.tab_9 = QtGui.QWidget()
        self.tab_9.setObjectName(_fromUtf8("tab_9"))
        self.gridLayout_10 = QtGui.QGridLayout(self.tab_9)
        self.gridLayout_10.setObjectName(_fromUtf8("gridLayout_10"))
        self.label_53 = QtGui.QLabel(self.tab_9)
        self.label_53.setObjectName(_fromUtf8("label_53"))
        self.gridLayout_10.addWidget(self.label_53, 0, 0, 1, 1)
        self.tabWidgetNorth_2.addTab(self.tab_9, _fromUtf8(""))
        self.tab_10 = QtGui.QWidget()
        self.tab_10.setObjectName(_fromUtf8("tab_10"))
        self.gridLayout_19 = QtGui.QGridLayout(self.tab_10)
        self.gridLayout_19.setObjectName(_fromUtf8("gridLayout_19"))
        self.label_49 = QtGui.QLabel(self.tab_10)
        self.label_49.setObjectName(_fromUtf8("label_49"))
        self.gridLayout_19.addWidget(self.label_49, 0, 0, 1, 1)
        self.tabWidgetNorth_2.addTab(self.tab_10, _fromUtf8(""))
        self.gridLayout_5.addWidget(self.tabWidgetNorth_2, 1, 1, 1, 1)
        self.tabWidgetWest = QtGui.QTabWidget(self.dockWidgetContents)
        self.tabWidgetWest.setTabPosition(QtGui.QTabWidget.West)
        self.tabWidgetWest.setObjectName(_fromUtf8("tabWidgetWest"))
        self.tab_5 = QtGui.QWidget()
        self.tab_5.setObjectName(_fromUtf8("tab_5"))
        self.gridLayout_3 = QtGui.QGridLayout(self.tab_5)
        self.gridLayout_3.setObjectName(_fromUtf8("gridLayout_3"))
        self.label_39 = QtGui.QLabel(self.tab_5)
        self.label_39.setObjectName(_fromUtf8("label_39"))
        self.gridLayout_3.addWidget(self.label_39, 0, 0, 1, 1)
        self.tabWidgetWest.addTab(self.tab_5, _fromUtf8(""))
        self.tab_6 = QtGui.QWidget()
        self.tab_6.setObjectName(_fromUtf8("tab_6"))
        self.gridLayout_9 = QtGui.QGridLayout(self.tab_6)
        self.gridLayout_9.setObjectName(_fromUtf8("gridLayout_9"))
        self.label_54 = QtGui.QLabel(self.tab_6)
        self.label_54.setObjectName(_fromUtf8("label_54"))
        self.gridLayout_9.addWidget(self.label_54, 0, 0, 1, 1)
        self.tabWidgetWest.addTab(self.tab_6, _fromUtf8(""))
        self.gridLayout_5.addWidget(self.tabWidgetWest, 2, 0, 1, 1)
        self.tabWidgetWest_2 = QtGui.QTabWidget(self.dockWidgetContents)
        self.tabWidgetWest_2.setEnabled(False)
        self.tabWidgetWest_2.setTabPosition(QtGui.QTabWidget.West)
        self.tabWidgetWest_2.setObjectName(_fromUtf8("tabWidgetWest_2"))
        self.tab_11 = QtGui.QWidget()
        self.tab_11.setObjectName(_fromUtf8("tab_11"))
        self.gridLayout_20 = QtGui.QGridLayout(self.tab_11)
        self.gridLayout_20.setObjectName(_fromUtf8("gridLayout_20"))
        self.label_50 = QtGui.QLabel(self.tab_11)
        self.label_50.setObjectName(_fromUtf8("label_50"))
        self.gridLayout_20.addWidget(self.label_50, 0, 0, 1, 1)
        self.tabWidgetWest_2.addTab(self.tab_11, _fromUtf8(""))
        self.tab_12 = QtGui.QWidget()
        self.tab_12.setObjectName(_fromUtf8("tab_12"))
        self.gridLayout_21 = QtGui.QGridLayout(self.tab_12)
        self.gridLayout_21.setObjectName(_fromUtf8("gridLayout_21"))
        self.label_72 = QtGui.QLabel(self.tab_12)
        self.label_72.setObjectName(_fromUtf8("label_72"))
        self.gridLayout_21.addWidget(self.label_72, 0, 0, 1, 1)
        self.tabWidgetWest_2.addTab(self.tab_12, _fromUtf8(""))
        self.gridLayout_5.addWidget(self.tabWidgetWest_2, 2, 1, 1, 1)
        self.tabWidgetEast = QtGui.QTabWidget(self.dockWidgetContents)
        self.tabWidgetEast.setTabPosition(QtGui.QTabWidget.East)
        self.tabWidgetEast.setObjectName(_fromUtf8("tabWidgetEast"))
        self.tab_3 = QtGui.QWidget()
        self.tab_3.setObjectName(_fromUtf8("tab_3"))
        self.gridLayout_2 = QtGui.QGridLayout(self.tab_3)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.label_38 = QtGui.QLabel(self.tab_3)
        self.label_38.setObjectName(_fromUtf8("label_38"))
        self.gridLayout_2.addWidget(self.label_38, 0, 0, 1, 1)
        self.tabWidgetEast.addTab(self.tab_3, _fromUtf8(""))
        self.tab_4 = QtGui.QWidget()
        self.tab_4.setObjectName(_fromUtf8("tab_4"))
        self.gridLayout_11 = QtGui.QGridLayout(self.tab_4)
        self.gridLayout_11.setObjectName(_fromUtf8("gridLayout_11"))
        self.label_55 = QtGui.QLabel(self.tab_4)
        self.label_55.setObjectName(_fromUtf8("label_55"))
        self.gridLayout_11.addWidget(self.label_55, 0, 0, 1, 1)
        self.tabWidgetEast.addTab(self.tab_4, _fromUtf8(""))
        self.gridLayout_5.addWidget(self.tabWidgetEast, 3, 0, 1, 1)
        self.tabWidgetEast_2 = QtGui.QTabWidget(self.dockWidgetContents)
        self.tabWidgetEast_2.setEnabled(False)
        self.tabWidgetEast_2.setTabPosition(QtGui.QTabWidget.East)
        self.tabWidgetEast_2.setObjectName(_fromUtf8("tabWidgetEast_2"))
        self.tab_13 = QtGui.QWidget()
        self.tab_13.setObjectName(_fromUtf8("tab_13"))
        self.gridLayout_22 = QtGui.QGridLayout(self.tab_13)
        self.gridLayout_22.setObjectName(_fromUtf8("gridLayout_22"))
        self.label_51 = QtGui.QLabel(self.tab_13)
        self.label_51.setObjectName(_fromUtf8("label_51"))
        self.gridLayout_22.addWidget(self.label_51, 0, 0, 1, 1)
        self.tabWidgetEast_2.addTab(self.tab_13, _fromUtf8(""))
        self.tab_14 = QtGui.QWidget()
        self.tab_14.setObjectName(_fromUtf8("tab_14"))
        self.gridLayout_30 = QtGui.QGridLayout(self.tab_14)
        self.gridLayout_30.setObjectName(_fromUtf8("gridLayout_30"))
        self.label_73 = QtGui.QLabel(self.tab_14)
        self.label_73.setObjectName(_fromUtf8("label_73"))
        self.gridLayout_30.addWidget(self.label_73, 0, 0, 1, 1)
        self.tabWidgetEast_2.addTab(self.tab_14, _fromUtf8(""))
        self.gridLayout_5.addWidget(self.tabWidgetEast_2, 3, 1, 1, 1)
        self.tabWidgetSouth = QtGui.QTabWidget(self.dockWidgetContents)
        self.tabWidgetSouth.setTabPosition(QtGui.QTabWidget.South)
        self.tabWidgetSouth.setTabsClosable(True)
        self.tabWidgetSouth.setObjectName(_fromUtf8("tabWidgetSouth"))
        self.tab = QtGui.QWidget()
        self.tab.setObjectName(_fromUtf8("tab"))
        self.gridLayout = QtGui.QGridLayout(self.tab)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.label_34 = QtGui.QLabel(self.tab)
        self.label_34.setObjectName(_fromUtf8("label_34"))
        self.gridLayout.addWidget(self.label_34, 0, 0, 1, 1)
        self.tabWidgetSouth.addTab(self.tab, _fromUtf8(""))
        self.tab_2 = QtGui.QWidget()
        self.tab_2.setObjectName(_fromUtf8("tab_2"))
        self.gridLayout_18 = QtGui.QGridLayout(self.tab_2)
        self.gridLayout_18.setObjectName(_fromUtf8("gridLayout_18"))
        self.label_62 = QtGui.QLabel(self.tab_2)
        self.label_62.setObjectName(_fromUtf8("label_62"))
        self.gridLayout_18.addWidget(self.label_62, 0, 0, 1, 1)
        self.tabWidgetSouth.addTab(self.tab_2, _fromUtf8(""))
        self.gridLayout_5.addWidget(self.tabWidgetSouth, 4, 0, 1, 1)
        self.tabWidgetSouth_2 = QtGui.QTabWidget(self.dockWidgetContents)
        self.tabWidgetSouth_2.setEnabled(False)
        self.tabWidgetSouth_2.setTabPosition(QtGui.QTabWidget.South)
        self.tabWidgetSouth_2.setTabsClosable(True)
        self.tabWidgetSouth_2.setObjectName(_fromUtf8("tabWidgetSouth_2"))
        self.tab_15 = QtGui.QWidget()
        self.tab_15.setObjectName(_fromUtf8("tab_15"))
        self.gridLayout_31 = QtGui.QGridLayout(self.tab_15)
        self.gridLayout_31.setObjectName(_fromUtf8("gridLayout_31"))
        self.label_35 = QtGui.QLabel(self.tab_15)
        self.label_35.setObjectName(_fromUtf8("label_35"))
        self.gridLayout_31.addWidget(self.label_35, 0, 0, 1, 1)
        self.tabWidgetSouth_2.addTab(self.tab_15, _fromUtf8(""))
        self.tab_16 = QtGui.QWidget()
        self.tab_16.setObjectName(_fromUtf8("tab_16"))
        self.gridLayout_32 = QtGui.QGridLayout(self.tab_16)
        self.gridLayout_32.setObjectName(_fromUtf8("gridLayout_32"))
        self.label_74 = QtGui.QLabel(self.tab_16)
        self.label_74.setObjectName(_fromUtf8("label_74"))
        self.gridLayout_32.addWidget(self.label_74, 0, 0, 1, 1)
        self.tabWidgetSouth_2.addTab(self.tab_16, _fromUtf8(""))
        self.gridLayout_5.addWidget(self.tabWidgetSouth_2, 4, 1, 1, 1)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        self.tabWidgetNorth.setCurrentIndex(0)
        self.tabWidgetNorth_2.setCurrentIndex(1)
        self.tabWidgetWest.setCurrentIndex(0)
        self.tabWidgetWest_2.setCurrentIndex(0)
        self.tabWidgetEast.setCurrentIndex(0)
        self.tabWidgetEast_2.setCurrentIndex(0)
        self.tabWidgetSouth.setCurrentIndex(0)
        self.tabWidgetSouth_2.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        DockWidget.setWindowTitle(_translate("DockWidget", "Containers - Tabs", None))
        self.label_5.setText(_translate("DockWidget", "Enabled", None))
        self.label_6.setText(_translate("DockWidget", "Disabled", None))
        self.label_52.setText(_translate("DockWidget", "Inside TabWidget North Closable Tab 1", None))
        self.tabWidgetNorth.setTabText(self.tabWidgetNorth.indexOf(self.tab_7), _translate("DockWidget", "Tab 1", None))
        self.label_48.setText(_translate("DockWidget", "Inside TabWidget North Closable Tab 2", None))
        self.tabWidgetNorth.setTabText(self.tabWidgetNorth.indexOf(self.tab_8), _translate("DockWidget", "Tab 2", None))
        self.label_53.setText(_translate("DockWidget", "Inside TabWidget North Closable Tab 1", None))
        self.tabWidgetNorth_2.setTabText(self.tabWidgetNorth_2.indexOf(self.tab_9), _translate("DockWidget", "Tab 1", None))
        self.label_49.setText(_translate("DockWidget", "Inside TabWidget North Closable Tab 2", None))
        self.tabWidgetNorth_2.setTabText(self.tabWidgetNorth_2.indexOf(self.tab_10), _translate("DockWidget", "Tab 2", None))
        self.label_39.setText(_translate("DockWidget", "Inside TabWidget West Tab 1", None))
        self.tabWidgetWest.setTabText(self.tabWidgetWest.indexOf(self.tab_5), _translate("DockWidget", "Tab 1", None))
        self.label_54.setText(_translate("DockWidget", "Inside TabWidget West Tab 2", None))
        self.tabWidgetWest.setTabText(self.tabWidgetWest.indexOf(self.tab_6), _translate("DockWidget", "Tab 2", None))
        self.label_50.setText(_translate("DockWidget", "Inside TabWidget West Tab 1", None))
        self.tabWidgetWest_2.setTabText(self.tabWidgetWest_2.indexOf(self.tab_11), _translate("DockWidget", "Tab 1", None))
        self.label_72.setText(_translate("DockWidget", "Inside TabWidget West Tab 2", None))
        self.tabWidgetWest_2.setTabText(self.tabWidgetWest_2.indexOf(self.tab_12), _translate("DockWidget", "Tab 2", None))
        self.label_38.setText(_translate("DockWidget", "Inside TabWidget East Tab 1", None))
        self.tabWidgetEast.setTabText(self.tabWidgetEast.indexOf(self.tab_3), _translate("DockWidget", "Tab 1", None))
        self.label_55.setText(_translate("DockWidget", "Inside TabWidget East Tab 2", None))
        self.tabWidgetEast.setTabText(self.tabWidgetEast.indexOf(self.tab_4), _translate("DockWidget", "Tab 2", None))
        self.label_51.setText(_translate("DockWidget", "Inside TabWidget East Tab 1", None))
        self.tabWidgetEast_2.setTabText(self.tabWidgetEast_2.indexOf(self.tab_13), _translate("DockWidget", "Tab 1", None))
        self.label_73.setText(_translate("DockWidget", "Inside TabWidget East Tab 2", None))
        self.tabWidgetEast_2.setTabText(self.tabWidgetEast_2.indexOf(self.tab_14), _translate("DockWidget", "Tab 2", None))
        self.label_34.setText(_translate("DockWidget", "Inside TabWidget South Closable Tab 1", None))
        self.tabWidgetSouth.setTabText(self.tabWidgetSouth.indexOf(self.tab), _translate("DockWidget", "Tab 1", None))
        self.label_62.setText(_translate("DockWidget", "Inside TabWidget South Closable Tab 2", None))
        self.tabWidgetSouth.setTabText(self.tabWidgetSouth.indexOf(self.tab_2), _translate("DockWidget", "Tab 2", None))
        self.label_35.setText(_translate("DockWidget", "Inside TabWidget South Closable Tab 1", None))
        self.tabWidgetSouth_2.setTabText(self.tabWidgetSouth_2.indexOf(self.tab_15), _translate("DockWidget", "Tab 1", None))
        self.label_74.setText(_translate("DockWidget", "Inside TabWidget South Closable Tab 2", None))
        self.tabWidgetSouth_2.setTabText(self.tabWidgetSouth_2.indexOf(self.tab_16), _translate("DockWidget", "Tab 2", None))

